==> monitor-1.30.tar.bz2: monitor-1.30/results.cpp <==
#include <errno.h>
#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include  <iostream>
#include <iomanip>
#include <map>
#include <sstream>
#include <string>

#include "defnames.h"
#include "astrotime.h"
#include "results.h"

AstroDateTime utc_out;

namespace {
    std::ostream& operator<<( std::ostream& stm, const std::ostringstream& str ){
        std::cout << str.str() << std::endl;
        stm << str.str() << std::endl;
        return stm;
    }
}

std::string Result::headstamp( const std::string& pref ) {
    utc_out.current(CONV);
    std::ostringstream t( pref + ' ' + utc_out.strDate() + ' ' + utc_out.strTime(0) + ' ' );
    return t.str();
}

Result::Result( Config& cfg ) {
    std::map<std::string,std::string> rPs;
    std::string str;
    bool append;
    std::string filename =  program_res + std::string(utc_out.strFileName())+extension_out;
    rfile.open( filename.c_str(), std::ios::in );
    if( ( append = rfile ) ){
        unsigned int i = 0;
        const unsigned int j = 22;          //    
        while( getline( rfile, str ) ){      //     P 
            if( str[0] != 'P' ) continue;
            if( (i =  str.find( "=", j )) != std::string::npos ) rPs[str.substr( j, i-j )] = str.substr(i);
            std::cout << str << std::endl;
        }
    }
    rfile.clear();
    if( append ) rfile.close();
    rfile.open( filename.c_str(), std::ios::out | std::ios::app );
    if( !rfile ) throw ErrFat( (ErrorsCode)errno, filename );
    rfile << comstamp() << progname << VERSION << " Compiled " << __TIME__ << " " << __DATE__<< std::endl;
    for( int i=0; i< (&cfg)->size(); i++ ) {
        unsigned int j = (&cfg)->Pstr(i).find( "=", 0 );
        if( rPs.find((&cfg)->Pstr(i).substr( 0, j )) == rPs.end() ||
            rPs[(&cfg)->Pstr(i).substr( 0, j )] != (&cfg)->Pstr(i).substr( j ) ) {
            std::ostringstream padd( parstamp() + (&cfg)->Pstr(i) );
            rfile << padd;
         }
    }
    rPs.clear();
//    std::cerr << "Constructor Result\n";
}

Result::~Result() {
//    std::cerr << "Destructor Result\n";
    utc_out.current(CONV);
    rfile <<  comstamp() << "Parked" << std::endl;
    rfile.close();
}

void Result::meteoAccResults( MonitorInfo& d ) {
    utc_out.current(CONV);
    std::ostringstream outstr;
    outstr << headstamp( "M" ) << std::fixed << std::setprecision(1)
           << std::setw(6) << d.temperature1 << std::setw(6) << d.temperature2
           << std::setw(6) << d.wind_speed << std::setw(6) << d.wind_max
           << std::setprecision(0) << std::setw(5) << d.wind_direction
           << std::setprecision(1) << std::setw(6) << d.humidity
           << std::setw(6) << d.pressure
           << std::setw(6) << d.dew_point
           << std::setw(7) << d.generator_rps
           << std::setprecision(2) << std::setw(7) << d.accum_voltage
           << std::setprecision(1) << std::setw(6) << d.actuat_temper
           << std::setprecision(2) << std::setw(7) << d.actuat_voltage
           << std::setw(4) << ( d.switch1    ? "on" : "off" )
           << std::setw(4) << ( d.switch2    ? "on" : "off" )
           << std::setprecision(1) << std::setw(6) << d.skys_amb
           << std::setprecision(1) << std::setw(6) << d.skys_sens
           << std::setprecision(1) << std::setw(6) << d.skys_sky - d.skys_amb
           << std::setw(3) << d.skys_stat;
    rfile << outstr;
    data_copy = outstr.str().substr(2,outstr.str().size()-1);
}

void Result::meteoResults( MonitorInfo& d ) {
    utc_out.current(CONV);
    std::ostringstream outstr;
    outstr << headstamp( "m" ) << std::fixed << std::setprecision(1)
           << std::setw(6) << d.temperature1 << std::setw(6) << d.temperature2
           << std::setw(6) << d.wind_speed
           << std::setprecision(0) << std::setw(5) << d.wind_direction
           << std::setprecision(1) << std::setw(6) << d.humidity << std::setw(6) << d.pressure
           << std::setw(7) << d.generator_rps
           << std::setprecision(2) << std::setw(7) << d.accum_voltage
           << std::setprecision(1) << std::setw(6) << d.actuat_temper
           << std::setprecision(2) << std::setw(7) << d.actuat_voltage
           << std::setw(4) << ( d.switch1    ? "on" : "off" )
           << std::setw(4) << ( d.switch2    ? "on" : "off" )
           << std::setprecision(1) << std::setw(6) << d.skys_amb
           << std::setprecision(1) << std::setw(6) << d.skys_sens
           << std::setprecision(1) << std::setw(6) << d.skys_sky - d.skys_amb
           << std::setw(3) << d.skys_stat;
    rfile << outstr;
}

==> monitor-1.31.tar.bz2: monitor-1.31/results.cpp <==
#include <errno.h>
#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include  <iostream>
#include <iomanip>
#include <map>
#include <sstream>
#include <string>

#include "defnames.h"
#include "astrotime.h"
#include "results.h"

AstroDateTime utc_out;

namespace {
    std::ostream& operator<<( std::ostream& stm, const std::ostringstream& str ){
        std::cout << str.str() << std::endl;
        stm << str.str() << std::endl;
        return stm;
    }
}

std::string Result::headstamp( const std::string& pref ) {
    utc_out.current(CONV);
    std::ostringstream t( pref + ' ' + utc_out.strDate() + ' ' + utc_out.strTime(0) + ' ' );
    return t.str();
}

Result::Result( Config& cfg ) {
    std::map<std::string,std::string> rPs;
    std::string str;
    bool append;
    std::string filename =  program_res + std::string(utc_out.strFileName())+extension_out;
    rfile.open( filename.c_str(), std::ios::in );
    if( ( append = rfile ) ){
        unsigned int i = 0;
        const unsigned int j = 22;          //    
        while( getline( rfile, str ) ){      //     P 
            if( str[0] != 'P' ) continue;
            if( (i =  str.find( "=", j )) != std::string::npos ) rPs[str.substr( j, i-j )] = str.substr(i);
            std::cout << str << std::endl;
        }
    }
    rfile.clear();
    if( append ) rfile.close();
    rfile.open( filename.c_str(), std::ios::out | std::ios::app );
    if( !rfile ) throw ErrFat( (ErrorsCode)errno, filename );
    rfile << comstamp() << progname << VERSION << " Compiled " << __TIME__ << " " << __DATE__<< std::endl;
    for( int i=0; i< (&cfg)->size(); i++ ) {
        unsigned int j = (&cfg)->Pstr(i).find( "=", 0 );
        if( rPs.find((&cfg)->Pstr(i).substr( 0, j )) == rPs.end() ||
            rPs[(&cfg)->Pstr(i).substr( 0, j )] != (&cfg)->Pstr(i).substr( j ) ) {
            std::ostringstream padd( parstamp() + (&cfg)->Pstr(i) );
            rfile << padd;
         }
    }
    rPs.clear();
//    std::cerr << "Constructor Result\n";
}

Result::~Result() {
//    std::cerr << "Destructor Result\n";
    utc_out.current(CONV);
    rfile <<  comstamp() << "Parked" << std::endl;
    rfile.close();
}

void Result::meteoAccResults( MonitorInfo& d ) {
    utc_out.current(CONV);
    std::ostringstream outstr;
    outstr << headstamp( "M" ) << std::fixed << std::setprecision(1)
           << std::setw(6) << d.temperature1 << std::setw(6) << d.temperature2
           << std::setw(6) << d.wind_speed << std::setw(6) << d.wind_max
           << std::setprecision(0) << std::setw(5) << d.wind_direction
           << std::setprecision(1) << std::setw(6) << d.humidity
           << std::setw(6) << d.pressure
           << std::setw(6) << d.dew_point
           << std::setw(7) << d.generator_rps
           << std::setprecision(2) << std::setw(7) << d.accum_voltage
           << std::setprecision(1) << std::setw(6) << d.actuat_temper
           << std::setprecision(2) << std::setw(7) << d.actuat_voltage
           << std::setw(4) << ( d.switch1    ? "on" : "off" )
           << std::setw(4) << ( d.switch2    ? "on" : "off" )
           << std::setprecision(1) << std::setw(6) << d.skys_amb
           << std::setprecision(1) << std::setw(6) << d.skys_sens
           << std::setprecision(1) << std::setw(6) << d.skys_sky - d.skys_amb
           << std::setw(3) << d.skys_stat << std::setprecision(3) << std::setw(6) << d.radiation;
    rfile << outstr;
    data_copy = outstr.str().substr(2,outstr.str().size()-1);
}

void Result::meteoResults( MonitorInfo& d ) {
    utc_out.current(CONV);
    std::ostringstream outstr;
    outstr << headstamp( "m" ) << std::fixed << std::setprecision(1)
           << std::setw(6) << d.temperature1 << std::setw(6) << d.temperature2
           << std::setw(6) << d.wind_speed
           << std::setprecision(0) << std::setw(5) << d.wind_direction
           << std::setprecision(1) << std::setw(6) << d.humidity << std::setw(6) << d.pressure
           << std::setw(7) << d.generator_rps
           << std::setprecision(2) << std::setw(7) << d.accum_voltage
           << std::setprecision(1) << std::setw(6) << d.actuat_temper
           << std::setprecision(2) << std::setw(7) << d.actuat_voltage
           << std::setw(4) << ( d.switch1    ? "on" : "off" )
           << std::setw(4) << ( d.switch2    ? "on" : "off" )
           << std::setprecision(1) << std::setw(6) << d.skys_amb
           << std::setprecision(1) << std::setw(6) << d.skys_sens
           << std::setprecision(1) << std::setw(6) << d.skys_sky - d.skys_amb
           << std::setw(3) << d.skys_stat << std::setprecision(3) << std::setw(6) << d.radiation;
    rfile << outstr;
}
